aboutsummaryrefslogtreecommitdiff
path: root/discord/flags.py
diff options
context:
space:
mode:
Diffstat (limited to 'discord/flags.py')
-rw-r--r--discord/flags.py18
1 files changed, 17 insertions, 1 deletions
diff --git a/discord/flags.py b/discord/flags.py
index 373a8957..1a3ca792 100644
--- a/discord/flags.py
+++ b/discord/flags.py
@@ -566,18 +566,34 @@ class Intents(BaseFlags):
@flag_value
def emojis(self):
- """:class:`bool`: Whether guild emoji related events are enabled.
+ """:class:`bool`: Alias of :attr:`.emojis_and_stickers`.
+
+ .. versionchanged:: 2.0
+ Changed to an alias.
+ """
+ return 1 << 3
+
+ @alias_flag_value
+ def emojis_and_stickers(self):
+ """:class:`bool`: Whether guild emoji and sticker related events are enabled.
+
+ .. versionadded:: 2.0
This corresponds to the following events:
- :func:`on_guild_emojis_update`
+ - :func:`on_guild_stickers_update`
This also corresponds to the following attributes and classes in terms of cache:
- :class:`Emoji`
+ - :class:`GuildSticker`
- :meth:`Client.get_emoji`
+ - :meth:`Client.get_sticker`
- :meth:`Client.emojis`
+ - :meth:`Client.stickers`
- :attr:`Guild.emojis`
+ - :attr:`Guild.stickers`
"""
return 1 << 3